==> moto-4.0.9.tar.gz: moto-4.0.9/tests/test_amp/test_amp_logging_config.py <==
import boto3
import sys
import unittest
from moto import mock_amp


@mock_amp
class TestAmpLoggingConfig(unittest.TestCase):
    def setUp(self) -> None:
        if sys.version_info < (3, 7):
            raise unittest.SkipTest(
                "Cannot test this in Py3.6; outdated botocore dependencies do not yet support this feature"
            )
        self.client = boto3.client("amp", region_name="us-east-2")

        workspace = self.client.create_workspace(alias="test", tags={"t": "v"})
        self.workspace_id = workspace["workspaceId"]

    def test_describe_logging(self):
        resp = self.client.describe_logging_configuration(workspaceId=self.workspace_id)
        resp.should.have.key("loggingConfiguration").equals({})

    def test_create_logging(self):
        resp = self.client.create_logging_configuration(
            workspaceId=self.workspace_id, logGroupArn="log/arn"
        )
        resp.should.have.key("status").equals({"statusCode": "ACTIVE"})

        resp = self.client.describe_logging_configuration(
            workspaceId=self.workspace_id
        )["loggingConfiguration"]
        resp.should.have.key("createdAt")
        resp.should.have.key("logGroupArn").equals("log/arn")
        resp.should.have.key("status").equals({"statusCode": "ACTIVE"})
        resp.should.have.key("workspace").equals(self.workspace_id)

    def test_update_logging(self):
        self.client.create_logging_configuration(
            workspaceId=self.workspace_id, logGroupArn="log/arn"
        )

        resp = self.client.update_logging_configuration(
            workspaceId=self.workspace_id, logGroupArn="log/arn2"
        )
        resp.should.have.key("status").equals({"statusCode": "ACTIVE"})

        resp = self.client.describe_logging_configuration(
            workspaceId=self.workspace_id
        )["loggingConfiguration"]
        resp.should.have.key("modifiedAt")
        resp.should.have.key("logGroupArn").equals("log/arn2")

    def test_delete_logging(self):
        resp = self.client.create_logging_configuration(
            workspaceId=self.workspace_id, logGroupArn="log/arn"
        )

        self.client.delete_logging_configuration(workspaceId=self.workspace_id)

        resp = self.client.describe_logging_configuration(workspaceId=self.workspace_id)
        resp.should.have.key("loggingConfiguration").equals({})

==> moto-4.2.1.dev26.tar.gz: moto-4.2.1.dev26/tests/test_amp/test_amp_logging_config.py <==
import boto3
import unittest
from moto import mock_amp


@mock_amp
class TestAmpLoggingConfig(unittest.TestCase):
    def setUp(self) -> None:
        self.client = boto3.client("amp", region_name="us-east-2")

        workspace = self.client.create_workspace(alias="test", tags={"t": "v"})
        self.workspace_id = workspace["workspaceId"]

    def test_describe_logging(self):
        resp = self.client.describe_logging_configuration(workspaceId=self.workspace_id)
        assert resp["loggingConfiguration"] == {}

    def test_create_logging(self):
        resp = self.client.create_logging_configuration(
            workspaceId=self.workspace_id, logGroupArn="log/arn"
        )
        assert resp["status"] == {"statusCode": "ACTIVE"}

        resp = self.client.describe_logging_configuration(
            workspaceId=self.workspace_id
        )["loggingConfiguration"]
        assert "createdAt" in resp
        assert resp["logGroupArn"] == "log/arn"
        assert resp["status"] == {"statusCode": "ACTIVE"}
        assert resp["workspace"] == self.workspace_id

    def test_update_logging(self):
        self.client.create_logging_configuration(
            workspaceId=self.workspace_id, logGroupArn="log/arn"
        )

        resp = self.client.update_logging_configuration(
            workspaceId=self.workspace_id, logGroupArn="log/arn2"
        )
        assert resp["status"] == {"statusCode": "ACTIVE"}

        resp = self.client.describe_logging_configuration(
            workspaceId=self.workspace_id
        )["loggingConfiguration"]
        assert "modifiedAt" in resp
        assert resp["logGroupArn"] == "log/arn2"

    def test_delete_logging(self):
        resp = self.client.create_logging_configuration(
            workspaceId=self.workspace_id, logGroupArn="log/arn"
        )

        self.client.delete_logging_configuration(workspaceId=self.workspace_id)

        resp = self.client.describe_logging_configuration(workspaceId=self.workspace_id)
        assert resp["loggingConfiguration"] == {}
